@@ -7,10 +7,6 @@ Usage:
 >>> for i in trange(10):
 ...     ...
 """
-# future division is important to divide integers and get as
-# a result precise floating numbers (instead of truncated int)
-from __future__ import absolute_import, division
-
 # import compatibility functions and utilities
 import re
 import sys
@@ -18,7 +14,6 @@ from weakref import proxy
 
 # to inherit from the tqdm class
 from .std import tqdm as std_tqdm
-from .utils import _range
 
 if True:  # pragma: no cover
     # import IPython/Jupyter base widget and display utilities
@@ -78,7 +73,7 @@ WARN_NOIPYW = ("IProgress not found. Please update jupyter and ipywidgets."
 
 class TqdmHBox(HBox):
     """`ipywidgets.HBox` with a pretty representation"""
-    def _repr_json_(self, pretty=None):
+    def _json_(self, pretty=None):
         pbar = getattr(self, 'pbar', None)
         if pbar is None:
             return {}
@@ -91,7 +86,7 @@ class TqdmHBox(HBox):
         pbar = getattr(self, 'pbar', None)
         if pbar is None:
             return super(TqdmHBox, self).__repr__()
-        return pbar.format_meter(**self._repr_json_(pretty))
+        return pbar.format_meter(**self._json_(pretty))
 
     def _repr_pretty_(self, pp, *_, **__):
         pp.text(self.__repr__(True))
@@ -169,7 +164,7 @@ class tqdm_notebook(std_tqdm):
         if msg:
             # html escape special characters (like '&')
             if '<bar/>' in msg:
-                left, right = map(escape, re.split(r'\|?<bar/>\|?', msg, 1))
+                left, right = map(escape, re.split(r'\|?<bar/>\|?', msg, maxsplit=1))
             else:
                 left, right = '', escape(msg)
 
@@ -192,6 +187,7 @@ class tqdm_notebook(std_tqdm):
                 self.container.close()
             except AttributeError:
                 self.container.visible = False
+            self.container.layout.visibility = 'hidden'  # IPYW>=8
 
         if check_delay and self.delay > 0 and not self.displayed:
             display(self.container)
@@ -254,7 +250,8 @@ class tqdm_notebook(std_tqdm):
 
     def __iter__(self):
         try:
-            for obj in super(tqdm_notebook, self).__iter__():
+            it = super(tqdm_notebook, self).__iter__()
+            for obj in it:
                 # return super(tqdm...) will not catch exception
                 yield obj
         # NB: except ... [ as ...] breaks IPython async KeyboardInterrupt
@@ -315,11 +312,8 @@ class tqdm_notebook(std_tqdm):
 
 
 def tnrange(*args, **kwargs):
-    """
-    A shortcut for `tqdm.notebook.tqdm(xrange(*args), **kwargs)`.
-    On Python3+, `range` is used instead of `xrange`.
-    """
-    return tqdm_notebook(_range(*args), **kwargs)
+    """Shortcut for `tqdm.notebook.tqdm(range(*args), **kwargs)`."""
+    return tqdm_notebook(range(*args), **kwargs)
 
 
 # Aliases
